Use Libtorrent in a virtualenv on Linux, Windows or OSX.
========================================================

Usage
-----

```pip install vext.libtorrent``` or add  ```vext.libtorrent``` to your requirements.txt


Dependencies
------------

libtorrent installed in the system python

Debian / Ubuntu

``` $ sudo apt-get install python-libtorrent```

SuSE

``` $ zypper install python-libtorrent``

Fedora, Redhat, Centos

``` $ yum install python-libtorrent```

Windows

Untested at this time, but should work.
